# Installation

This tutorial guides the user through the full installation process of Denario.

<div class="video-wrapper">
<iframe src="https://www.youtube.com/embed/TsIdUSEEKhA" frameborder="0"
                allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share"
                allowfullscreen></iframe>
</div>
